<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * Admin actions class
 */
class WCSS_Admin_Actions {

	public function __construct() {
		add_action( 'admin_init', array( $this, 'reset_settings' ), 5 );
		add_action( 'admin_init', array( $this, 'delete_saved_cart' ) );
		add_action( 'admin_init', array( $this, 'delete_saved_carts' ) );
		add_action( 'admin_init', array( $this, 'delete_shared_cart' ) );
		add_action( 'admin_init', array( $this, 'delete_shared_carts' ) );
		add_action( 'admin_init', array( $this, 'delete_shared_and_saved_carts' ) );
		add_action( 'admin_init', array( $this, 'flush_rewrite_rules' ) );

		add_action( 'admin_init', array( $this, 'save_shared_cart_for_user' ) );
	}

	/**
	 * Reset settings to default.
	 */
	public function reset_settings() {
		if ( isset( $_GET['wcss_reset_settings'] ) && wp_verify_nonce( $_GET['_wpnonce'] ) ) {

			WCSS_Settings::reset_options();

			wp_safe_redirect( wp_get_referer() );
			exit;
		}
	}

	public function delete_saved_cart() {
		if ( isset( $_GET['wcss_delete_saved_cart'] ) && wp_verify_nonce( $_GET['_wpnonce'] ) ) {
			wcss_delete_saved_cart( $_GET['wcss_delete_saved_cart'] );

			wp_safe_redirect( admin_url( 'admin.php?page=woocommerce-cart-share_saved-cart&wcss_delete_cart_done=1' ) );
			exit;
		}
	}

	/**
	 * Delete all saved cart.
	 */
	public function delete_saved_carts() {
		if ( isset( $_GET['wcss_delete_saved_carts'] ) && wp_verify_nonce( $_GET['wcss_delete_saved_carts'], 'wcss_delete_saved_carts' ) ) {
			global $wpdb;

			$wpdb->query( "DELETE FROM {$wpdb->prefix}wcss_shared_cart WHERE cart_key IN ( SELECT cart_key FROM {$wpdb->prefix}wcss_saved_cart )" );
			$wpdb->query( "DELETE FROM {$wpdb->prefix}wcss_shared_cart_meta WHERE cart_key IN ( SELECT cart_key FROM {$wpdb->prefix}wcss_saved_cart )" );
			$wpdb->query( "DELETE FROM {$wpdb->prefix}wcss_saved_cart" );

			wp_safe_redirect( wp_get_referer() );
			exit;
		}
	}

	/**
	 * Delete shared cart.
	 *
	 * @since 2.0.1
	 *
	 * @return void
	 */
	public function delete_shared_cart() {
		if ( ! isset( $_GET['wcss_delete_shared_cart'] ) || ! wp_verify_nonce( $_GET['_wpnonce'] ) ) {
			return;
		}

		wcss_delete_shared_cart( $_GET['wcss_delete_shared_cart'] );

		wp_safe_redirect( admin_url( 'admin.php?page=woocommerce-cart-share_shared-cart&wcss_delete_cart_done=1' ) );
		exit;
	}

	/**
	 * Delete all shared cart.
	 *
	 * @since 2.0.0
	 *
	 * @return void
	 */
	public function delete_shared_carts() {
		if ( isset( $_GET['wcss_delete_shared_carts'] ) && wp_verify_nonce( $_GET['wcss_delete_shared_carts'], 'wcss_delete_shared_carts' ) ) {
			global $wpdb;

			$wpdb->query( "DELETE FROM {$wpdb->prefix}wcss_shared_cart WHERE cart_key NOT IN ( SELECT cart_key FROM {$wpdb->prefix}wcss_saved_cart )" );
			$wpdb->query( "DELETE FROM {$wpdb->prefix}wcss_shared_cart_meta WHERE cart_key NOT IN ( SELECT cart_key FROM {$wpdb->prefix}wcss_saved_cart )" );

			wp_safe_redirect( wp_get_referer() );
			exit;
		}
	}

	/**
	 * Delete all shared and saved cart.
	 */
	public function delete_shared_and_saved_carts() {
		if ( isset( $_GET['wcss_delete_shared_and_saved_carts'] ) && wp_verify_nonce( $_GET['wcss_delete_shared_and_saved_carts'], 'wcss_delete_shared_and_saved_carts' ) ) {
			global $wpdb;

			$wpdb->query( "TRUNCATE TABLE {$wpdb->prefix}wcss_saved_cart" );
			$wpdb->query( "TRUNCATE TABLE {$wpdb->prefix}wcss_shared_cart" );
			$wpdb->query( "TRUNCATE TABLE {$wpdb->prefix}wcss_shared_cart_meta" );

			wp_safe_redirect( wp_get_referer() );
			exit;
		}
	}

	/**
	 * Flush rewrite rules.
	 */
	public function flush_rewrite_rules() {
		if ( isset( $_GET['wcss_flush_rewrite_rules'] ) && wp_verify_nonce( $_GET['_wpnonce'] ) ) {
			// Flush WP rewrite rules.
			update_option( 'rewrite_rules', '' );
			flush_rewrite_rules();

			// Redirects on plugin main page and 404 fix admin notification.
			wp_redirect( 'admin.php?page=woocommerce-cart-share&wcss_flush_rewrite_rules_notification_hide=1' );
			exit;
		}
	}

	/**
	 * Save shared cart for user.
	 *
	 * @since 2.0.0
	 *
	 * @return void
	 */
	public function save_shared_cart_for_user() {
		if (
			! isset( $_POST['wcss_admin_save_shared_cart_for_user'] ) ||
			! wp_verify_nonce( $_POST['wcss_admin_save_shared_cart_for_user'], 'wcss_admin_save_shared_cart_for_user' ) ) {
			return;
		}

		$user_id   = isset( $_POST['user_id'] ) ? absint( $_POST['user_id'] ) : '';
		$cart_name = isset( $_POST['cart_name'] ) ? sanitize_text_field( wp_unslash( $_POST['cart_name'] ) ) : '';
		$cart_key  = isset( $_POST['cart_key'] ) ? sanitize_text_field( wp_unslash( $_POST['cart_key'] ) ) : '';

		if ( ! $user_id || ! $cart_name || ! $cart_key ) {
			return;
		}

		wcss_insert_saved_cart( array(
			'user_id'   => $user_id,
			'cart_name' => $cart_name,
			'cart_key'  => $cart_key,
		) );

		$redirect_url = add_query_arg(
			array(
				'wcss_shared_cart_successfully_saved' => 'done',
			),
			$_POST['_wp_http_referer']
		);

		wp_safe_redirect( $redirect_url );

		exit;
	}

}

$wcss_admin_actions = new WCSS_Admin_Actions();
