<?php
// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';

class WCSS_Admin_Saved_Cart_Table extends WP_List_Table {

	private $_table_shared;
	private $_table_saved;

	/** Class constructor */
	public function __construct() {
		global $wpdb;

		$this->_table_shared = $wpdb->prefix . 'wcss_shared_cart';
		$this->_table_saved  = $wpdb->prefix . 'wcss_saved_cart';

		parent::__construct(
			array(
				'singular' => esc_html__( 'Saved Cart', 'woo-cart-share' ), // singular name of the listed records
				'plural'   => esc_html__( 'Saved Cart', 'woo-cart-share' ), // plural name of the listed records
				'ajax'     => false, // should this table support ajax?
			)
		);

	}

	public function prepare_items() {

		$order_by    = isset( $_GET['orderby'] ) ? trim( $_GET['orderby'] ) : '';
		$order       = isset( $_GET['order'] ) ? trim( $_GET['order'] ) : '';
		$search_term = isset( $_POST['s'] ) ? trim( $_POST['s'] ) : '';

		$data = $this->wp_list_table_data( $order_by, $order, $search_term );

		$pre_page     = $this->get_items_per_page( 'wcss_saved_cart_per_page', 20 );
		$currnet_page = $this->get_pagenum();
		$total_items  = count( $data );

		$this->set_pagination_args(
			array(
				'total_items' => $total_items,
				'per_page'    => $pre_page,
			)
		);

		$columns  = $this->get_columns();
		$hidden   = $this->get_hidden_columns();
		$sortable = $this->get_sortable_columns();

		$this->_column_headers = $this->get_column_info();
		$this->items           = array_slice( $data, ( ( $currnet_page - 1 ) * $pre_page ), $pre_page );

		$this->process_bulk_action();
	}

	public function wp_list_table_data( $order_by = '', $order = '', $search_term = '' ) {
		global $wpdb;

		// Search results.
		if ( '' !== $search_term ) {
			$query = $wpdb->get_results(
				"SELECT
                    saved.id id,
                    saved.user_id user_id,
                    users.user_login user_login,
                    saved.cart_name cart_name,
                    saved.cart_key cart_key,
                    saved.cart_saved cart_saved,
                    shared.cart_retrieved cart_retrieved,
                    shared.cart_retrieved_time cart_retrieved_time,
                    saved.cart_key actions
                FROM
                    $this->_table_saved saved
                INNER JOIN
                    $this->_table_shared shared
                ON
                    saved.cart_key = shared.cart_key
                INNER JOIN
                    $wpdb->users users
                ON
                    users.id = saved.user_id
                WHERE ( users.user_login LIKE '%$search_term%' )
                    OR ( saved.cart_name LIKE '%$search_term%' )
                    OR ( saved.cart_key LIKE '%$search_term%' )
                    OR ( shared.cart_retrieved LIKE '%$search_term%' )
                    OR ( shared.cart_retrieved_time LIKE '%$search_term%' )
                    OR ( saved.cart_saved LIKE '%$search_term%' )
                ORDER BY id DESC",
				ARRAY_A
			);
		} else { // Display all results.
			$query = $wpdb->get_results(
				"SELECT
                    saved.id id,
                    saved.user_id user_id,
                    users.user_login user_login,
                    saved.cart_name cart_name,
                    saved.cart_key cart_key,
                    saved.cart_saved cart_saved,
                    shared.cart_retrieved cart_retrieved,
                    shared.cart_retrieved_time cart_retrieved_time,
                    saved.cart_key actions
                FROM
                    $this->_table_saved saved
                INNER JOIN
                    $this->_table_shared shared
                ON
                    saved.cart_key = shared.cart_key
                INNER JOIN
                    $wpdb->users users
                ON
                    users.id = saved.user_id
                ORDER BY saved.id DESC",
				ARRAY_A
			);
		}

		// Orderd by
		if ( '' !== $order_by && '' !== $order ) {
			if ( 'user_login' === $order_by ) {
				if ( 'asc' === $order ) {
					usort( $query, $this->make_comparer( array( 'user_login', SORT_ASC ) ) );
				} else {
					usort( $query, $this->make_comparer( array( 'user_login', SORT_DESC ) ) );
				}
			}
			if ( 'cart_name' === $order_by ) {
				if ( 'asc' === $order ) {
					usort( $query, $this->make_comparer( array( 'cart_name', SORT_ASC ) ) );
				} else {
					usort( $query, $this->make_comparer( array( 'cart_name', SORT_DESC ) ) );
				}
			}
			if ( 'cart_key' === $order_by ) {
				if ( 'asc' === $order ) {
					usort( $query, $this->make_comparer( array( 'cart_key', SORT_ASC ) ) );
				} else {
					usort( $query, $this->make_comparer( array( 'cart_key', SORT_DESC ) ) );
				}
			}
			if ( 'cart_retrieved' === $order_by ) {
				if ( 'asc' === $order ) {
					usort( $query, $this->make_comparer( array( 'cart_retrieved', SORT_ASC ) ) );
				} else {
					usort( $query, $this->make_comparer( array( 'cart_retrieved', SORT_DESC ) ) );
				}
			}
			if ( 'cart_retrieved_time' === $order_by ) {
				if ( 'asc' === $order ) {
					usort( $query, $this->make_comparer( array( 'cart_retrieved_time', SORT_ASC ) ) );
				} else {
					usort( $query, $this->make_comparer( array( 'cart_retrieved_time', SORT_DESC ) ) );
				}
			}
			if ( 'cart_saved' === $order_by ) {
				if ( 'asc' === $order ) {
					usort( $query, $this->make_comparer( array( 'cart_saved', SORT_ASC ) ) );
				} else {
					usort( $query, $this->make_comparer( array( 'cart_saved', SORT_DESC ) ) );
				}
			}
		}

		return $query;
	}

	public function get_columns() {
		$columns = array(
			'cb'                  => '<input type="checkbox" />',
			'cart_key'            => esc_html__( 'Cart Key', 'woo-cart-share' ),
			'cart_name'           => esc_html__( 'Cart Name', 'woo-cart-share' ),
			'user_login'          => esc_html__( 'Saved By', 'woo-cart-share' ),
			'user_email'          => esc_html__( 'Email', 'woo-cart-share' ),
			'cart_retrieved'      => esc_html__( 'Cart Retrieved', 'woo-cart-share' ),
			'cart_retrieved_time' => esc_html__( 'Retrieved Time', 'woo-cart-share' ),
			'cart_saved'          => esc_html__( 'Cart Saved', 'woo-cart-share' ),
		);

		return $columns;
	}

	public function column_default( $item, $column_name ) {
		$user = get_userdata( $item['user_id'] );

		switch ( $column_name ) {
			case 'user_login':
				return '<a href="' . admin_url( 'user-edit.php?user_id=' . intval( $item['user_id'] ) ) . '">' . $item[ $column_name ] . '</a>';
			case 'user_email':
				return esc_attr( $user->user_email );
			case 'cart_key':
				return '<a href="' . wcss_get_cart_link( $item['cart_key'] ) . '">' . $item[ $column_name ] . '</a>';
			case 'cart_retrieved':
				return intval( $item['cart_retrieved'] );
			case 'cart_retrieved_time':
				return esc_html( wcss_date( $item['cart_retrieved_time'] ) );
			case 'cart_name':
				return $item[ $column_name ];
			case 'cart_saved':
				return esc_html( wcss_date( $item['cart_saved'] ) );
			default:
				return __( 'No Value', 'woo-cart-share' );
		}
	}

	public function get_hidden_columns() {
		return array();
	}

	public function get_sortable_columns() {
		return array(
			'user_login'          => array( 'user_login', false ),
			'cart_name'           => array( 'cart_name', false ),
			'cart_key'            => array( 'cart_key', false ),
			'cart_retrieved'      => array( 'cart_retrieved', false ),
			'cart_retrieved_time' => array( 'cart_retrieved_time', false ),
			'cart_saved'          => array( 'cart_saved', false ),
		);
	}

	public function column_cb( $item ) {
		return sprintf( '<input type="checkbox" name="saved_carts[]" value="%s" />', $item['cart_key'] );
	}

	/**
	 * Cart Key column.
	 *
	 * @since 2.0.1
	 *
	 * @param array $item Item array.
	 * @return string
	 */
	public function column_cart_key( $item ) {
		$actions = array(
			'view'   => wp_sprintf( '<a href="%s">%s</a>', admin_url( 'admin.php?page=woocommerce-cart-share_saved-cart&cart_key=' . $item['cart_key'] ), esc_html__( 'View', 'woo-cart-share' ) ),
			'copy'   => sprintf( '<a href="%1$s" onclick="navigator.clipboard.writeText(\'%1$s\')">%2$s</a>', wcss_get_cart_link( $item['cart_key'] ), esc_html__( 'Copy Cart Link', 'woo-cart-share' ) ),
			'delete' => wp_sprintf( '<a href="%s" onclick="return confirm( \'%s\' )">%s</a>', wp_nonce_url( admin_url( '?wcss_delete_saved_cart=' . $item['cart_key'] ) ), esc_attr__( 'Are you sure?', 'woo-cart-share' ), esc_html__( 'Delete', 'woo-cart-share' ) ),
		);

		return sprintf( '%1$s %2$s', $item['cart_key'], $this->row_actions( $actions ) );
	}

	/**
	 * Custom bulk actions.
	 *
	 * @since 2.0.0
	 *
	 * @return array Array of bulk actions.
	 */
	public function get_bulk_actions() {
		return array(
			'delete' => esc_html__( 'Delete', 'woo-cart-share' ),
		);
	}

	/**
	 * Process custom bulk actions.
	 *
	 * @since 2.0.0
	 *
	 * @return void
	 */
	public function process_bulk_action() {

		// security check!
		if ( isset( $_POST['_wpnonce'] ) && ! empty( $_POST['_wpnonce'] ) ) {

			$nonce  = wp_unslash( $_POST['_wpnonce'] );
			$action = 'bulk-' . $this->_args['plural'];

			if ( ! wp_verify_nonce( $nonce, $action ) ) {
				return;
			}
		}

		$action = $this->current_action();

		if ( 'delete' === $action ) {
			$saved_cart_keys = wp_unslash( $_POST['saved_carts'] );

			if ( $saved_cart_keys ) {
				foreach ( $saved_cart_keys as $saved_cart_key ) {
					wcss_delete_saved_cart( $saved_cart_key );
				}
			}

			wp_redirect( admin_url( 'admin.php?page=woocommerce-cart-share_saved-cart' ) );
			exit;
		}
	}

	public function make_comparer() {
		// Normalize criteria up front so that the comparer finds everything tidy
		$criteria = func_get_args();
		foreach ( $criteria as $index => $criterion ) {
			$criteria[ $index ] = is_array( $criterion )
				? array_pad( $criterion, 3, null )
				: array( $criterion, SORT_ASC, null );
		}

		return function( $first, $second ) use ( &$criteria ) {
			foreach ( $criteria as $criterion ) {
				// How will we compare this round?
				list($column, $sortOrder, $projection) = $criterion;
				$sortOrder                             = $sortOrder === SORT_DESC ? -1 : 1;

				// If a projection was defined project the values now
				if ( $projection ) {
					$lhs = call_user_func( $projection, $first[ $column ] );
					$rhs = call_user_func( $projection, $second[ $column ] );
				} else {
					$lhs = $first[ $column ];
					$rhs = $second[ $column ];
				}

				// Do the actual comparison; do not return if equal
				if ( $lhs < $rhs ) {
					return -1 * $sortOrder;
				} elseif ( $lhs > $rhs ) {
					return 1 * $sortOrder;
				}
			}

			return 0; // tiebreakers exhausted, so $first == $second
		};
	}

	/**
	 * Add screen option.
	 *
	 * @since 2.0.1
	 *
	 * @return void
	 */
	public static function add_screen_option() {
		$args = array(
			'label'   => esc_html__( 'Number of items per page:', 'woo-cart-share' ),
			'default' => 20,
			'option'  => 'wcss_saved_cart_per_page'
		);

		add_screen_option( 'per_page', $args );

		$wcss_admin_saved_cart_table = new WCSS_Admin_Saved_Cart_Table();
	}

	/**
	 * Set screen option.
	 *
	 * @since 2.0.1
	 *
	 * @link https://developer.wordpress.org/reference/hooks/set-screen-option/
	 *
	 * @param mixed  $status The value to save instead of the option value. Default false.
	 * @param string $option The option name.
	 * @param int    $value  The option value.
	 * @return int Filtered option value.
	 */
	public static function set_screen_option( $status, $option, $value ) {
		return $value;
	}

}
