<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * This class is responsiable for the plugin migration with old version.
 *
 * @since 1.7
 */
class WCSS_Migration {

	protected $db_plugin_version = '';

	public function __construct() {
		$this->db_plugin_version = $this->get_db_plugin_version();

		add_action( 'wcss_before_install', array( $this, 'migration_options_1_6_to_1_7' ), 1 );
		add_action( 'wcss_before_install', array( $this, 'migration_options_1_7_5' ), 2 );
		add_action( 'wcss_before_install', array( $this, 'migration_options_1_7_6' ), 3 );
		add_action( 'wcss_before_install', array( $this, 'migration_options_1_7_7' ), 4 );
		add_action( 'wcss_before_install', array( $this, 'migration_options_1_9_0' ), 5 );
		add_action( 'wcss_before_install', array( $this, 'migration_options_2_0_0' ), 6 );
	}

	public function migration_options_1_6_to_1_7() {
		/**
		 * If older version was never installed then no need to run migration.
		 */
		if ( ! get_option( 'wcz_wcs_settings' ) ) {
			return;
		}

		// Main settings migration
		$main_settings = get_option( 'wcz_wcs_settings', array() );

		$wcss_share_media = array();

		foreach ( $main_settings as $name => $value ) {
			if ( $name === 'ui_btn_bg_color' ) {
				$this->add_option( 'wcss_button_background_color', $value );
			}
			if ( $name === 'ui_btn_text_color' ) {
				$this->add_option( 'wcss_button_text_color', $value );
			}
			if ( $name === 'ui_popup_bg_color' ) {
				$this->add_option( 'wcss_popup_background_color', $value );
			}
			if ( $name === 'ui_popup_text_color' ) {
				$this->add_option( 'wcss_popup_text_color', $value );
			}
			if ( $name === 'text_share_cart_btn' ) {
				$this->add_option( 'wcss_share_cart_button_text', $value );
			}
			if ( $name === 'text_share_cart_title' ) {
				$this->add_option( 'wcss_share_cart_title', $value );
			}
			if ( $name === 'text_save_cart_msg' ) {
				$this->add_option( 'wcss_save_cart_message', $value );
			}
			if ( $name === 'text_save_cart_input_placeholder' ) {
				$this->add_option( 'wcss_save_cart_input_placeholder', $value );
			}
			if ( $name === 'text_save_cart_btn' ) {
				$this->add_option( 'wcss_save_cart_button_text', $value );
			}
			if ( $name === 'text_save_cart_not_logged_in_msg' ) {
				$this->add_option( 'wcss_save_cart_not_logged_in_message', $value );
			}
			if ( $name === 'text_empty_cart_msg' ) {
				$this->add_option( 'wcss_empty_cart_message', $value );
			}
			if ( $name === 'text_email_to' ) {
				$this->add_option( 'wcss_share_cart_email_to_label', $value );
			}
			if ( $name === 'text_email_subject' ) {
				$this->add_option( 'wcss_share_cart_email_subject_label', $value );
			}
			if ( $name === 'text_email_message' ) {
				$this->add_option( 'wcss_share_cart_email_message_label', $value );
			}
			if ( $name === 'opt_share_cart_btn_location' ) {
				$this->add_option( 'wcss_trigger_button_location', $value );
			}
			if ( $name === 'opt_user_can_save_cart' ) {
				$this->add_option( 'wcss_user_can_save_cart', ( $value === 'yes' ) ? 'yes' : 'no' );
			}
			if ( $name === 'opt_user_can_print_cart' ) {
				$this->add_option( 'wcss_user_can_print_cart', ( $value === 'yes' ) ? 'yes' : 'no' );
			}
			if ( $name === 'opt_social_share_msg' ) {
				$this->add_option( 'wcss_social_share_message', $value );
			}
			if ( $name === 'opt_custom_css' ) {
				$this->add_option( 'wcss_custom_css', $value );
			}
			if ( $name === 'opt_is_rtl' ) {
				$this->add_option( 'wcss_rtl_status', ( $value === '0' ) ? 'no' : 'yes' );
			}
			if ( $name === 'opt_redirection_url' ) {
				$this->add_option( 'wcss_retrieved_cart_redirection_url', $value );
			}
			if ( $name === 'opt_roles_status' ) {
				$this->add_option( 'wcss_display_by_role_status', ( $value === '0' ) ? 'no' : 'yes' );
			}
			if ( $name === 'opt_roles' ) {
				$this->add_option( 'wcss_display_by_role', $value );
			}
			if ( $name === 'social_media' ) {
				foreach ( $value as $n => $v ) {
					if ( $n === 'whatsapp' ) {
						$wcss_share_media['whatsapp'] = ( $v == '1' ) ? 'yes' : 'no';
					}
					if ( $n === 'email' ) {
						$wcss_share_media['email'] = ( $v == '1' ) ? 'yes' : 'no';
					}
					if ( $n === 'copyLink' ) {
						$wcss_share_media['copy_link'] = ( $v == '1' ) ? 'yes' : 'no';
					}
					if ( $n === 'facebook' ) {
						$wcss_share_media['facebook'] = ( $v == '1' ) ? 'yes' : 'no';
					}
					if ( $n === 'twitter' ) {
						$wcss_share_media['twitter'] = ( $v == '1' ) ? 'yes' : 'no';
					}
					if ( $n === 'skype' ) {
						$wcss_share_media['skype'] = ( $v == '1' ) ? 'yes' : 'no';
					}
					if ( $n === 'messenger' ) {
						$wcss_share_media['messenger'] = ( $v == '1' ) ? 'yes' : 'no';
					}
				}

				$this->add_option( 'wcss_share_media', $wcss_share_media );
			}
		}

		// Email settings migration
		$email_settings = get_option( 'wcss_email_settings', array() );

		$email_follow_media = array();

		foreach ( $email_settings as $name => $value ) {
			if ( $name === 'brand_logo' ) {
				$this->add_option( 'wcss_email_brand_logo_url', $value );
			}
			if ( $name === 'brand_name' ) {
				$this->add_option( 'wcss_email_brand_name', $value );
			}
			if ( $name === 'header_bg_color' ) {
				$this->add_option( 'wcss_email_header_background_color', $value );
			}
			if ( $name === 'header_text_color' ) {
				$this->add_option( 'wcss_email_header_text_color', $value );
			}
			if ( $name === 'button_bg_color' ) {
				$this->add_option( 'wcss_email_button_background_color', $value );
			}
			if ( $name === 'button_text_color' ) {
				$this->add_option( 'wcss_email_button_text_color', $value );
			}
			if ( $name === 'button_text' ) {
				$this->add_option( 'wcss_email_retrieve_cart_button_text', $value );
			}
			if ( $name === 'body_bg_color' ) {
				$this->add_option( 'wcss_email_body_background_color', $value );
			}
			if ( $name === 'description' ) {
				$this->add_option( 'wcss_email_description', $value );
			}
			if ( $name === 'follow_facebook' ) {
				$email_follow_media['facebook'] = $value;
			}
			if ( $name === 'follow_instagram' ) {
				$email_follow_media['instagram'] = $value;
			}
			if ( $name === 'follow_twitter' ) {
				$email_follow_media['twitter'] = $value;
			}
			if ( $name === 'follow_whatsapp' ) {
				$email_follow_media['whatsapp'] = $value;
			}
			if ( $name === 'email_from_name' ) {
				$this->add_option( 'wcss_email_from_name', $value );
			}
			if ( $name === 'email_from' ) {
				$this->add_option( 'wcss_email_from_email', $value );
			}
		}
		$this->add_option( 'wcss_email_contact_media', $email_follow_media );

		// My account settings migration
		$my_account_settings = get_option( 'wcss_my_account_setting', array() );
		foreach ( $my_account_settings as $name => $value ) {
			if ( $name === 'tab_name' ) {
				$this->add_option( 'wcss_my_account_tab_name', $value );
			}
			if ( $name === 'slug' ) {
				$this->add_option( 'wcss_my_account_tab_slug', $value );
			}
			if ( $name === 'no_saved_cart_button_text' ) {
				$this->add_option( 'wcss_my_account_empty_saved_cart_button_text', $value );
			}
			if ( $name === 'no_saved_cart_msg' ) {
				$this->add_option( 'wcss_my_account_empty_saved_cart_message', $value );
			}
		}

		// Developer settings migration
		$developer_settings = get_option( 'wcz_wcs_dev_settings', array() );
		foreach ( $developer_settings as $name => $value ) {
			if ( $name === 'base_url' ) {
				$this->add_option( 'wcss_base_slug', $value );
			}
			if ( $name === 'delete_setting' ) {
				$this->add_option( 'wcss_delete_all', ( $value == '0' ) ? 'no' : 'yes' );
			}
		}

		// Delete version 1.6 or less then 1.6 settings.
		delete_option( 'wcz_wcs_settings' );
		delete_option( 'wcss_my_account_setting' );
		delete_option( 'wcss_email_settings' );
		delete_option( 'wcz_wcs_dev_settings' );
	}

	public function migration_options_1_7_5() {
		global $wpdb;

		$tbl_shared_cart = $wpdb->prefix . 'wcss_shared_cart';

		if ( version_compare( $this->db_plugin_version, '1.7.5', '<' ) ) {
			if ( $wpdb->get_var( "SHOW TABLES LIKE '$tbl_shared_cart'" ) == $tbl_shared_cart ) {

				// Add `cart_retrieved_time` column in the `wcss_shared_cart` table.
				if ( $wpdb->get_var( "SHOW COLUMNS FROM $tbl_shared_cart LIKE 'cart_retrieved_time'" ) != 'cart_retrieved_time' ) {
					$wpdb->query( "ALTER TABLE $tbl_shared_cart ADD cart_retrieved_time VARCHAR(32) NOT NULL AFTER cart_retrieved" );
				}
			}
		}
	}

	public function migration_options_1_7_6() {
		if ( get_option( 'wcss_delete_shared_cart_after_retrieved' ) ) {

			add_option(
				'wcss_automatically_delete_cart_options',
				array(
					'shared_cart_after_retrieved' => get_option( 'wcss_delete_shared_cart_after_retrieved' ),
					'shared_and_saved_cart_after_retrieved' => get_option( 'wcss_delete_cart_after_retrieved' ),
				)
			);

			delete_option( 'wcss_delete_cart_after_retrieved' );
			delete_option( 'wcss_delete_shared_cart_after_retrieved' );
		}
	}

	public function migration_options_1_7_7() {
		if ( get_option( 'wcss_retrieved_cart_redirection_url' ) ) {
			$retrieved_cart_redirection_id = get_option( 'wcss_retrieved_cart_redirection_url' );

			if ( ! is_numeric( $retrieved_cart_redirection_id ) ) {
				add_option( 'wcss_retrieved_cart_redirection_page_id', get_option( 'woocommerce_cart_page_id' ) );
			} else {
				add_option( 'wcss_retrieved_cart_redirection_page_id', $retrieved_cart_redirection_id );
			}

			delete_option( 'wcss_retrieved_cart_redirection_url' );
		}
	}

	public function migration_options_1_9_0() {
		global $wpdb;

		$tbl_shared_cart = $wpdb->prefix . 'wcss_shared_cart';
		$tbl_saved_cart  = $wpdb->prefix . 'wcss_saved_cart';

		if ( version_compare( $this->db_plugin_version, '1.9.0', '<' ) ) {
			if ( $wpdb->get_var( "SHOW TABLES LIKE '$tbl_shared_cart'" ) == $tbl_shared_cart ) {

				// cart_shared_by column in the wcss_shared_cart table.
				if ( $wpdb->get_var( "SHOW COLUMNS FROM $tbl_shared_cart LIKE 'cart_shared_by'" ) != 'cart_shared_by' ) {
					$wpdb->query( "ALTER TABLE $tbl_shared_cart ADD cart_shared_by BIGINT NOT NULL DEFAULT '0' AFTER cart_value" );
				}
			}

			if ( $wpdb->get_var( "SHOW TABLES LIKE '$tbl_saved_cart'" ) == $tbl_saved_cart ) {

				//Update wcss_saved_cart.cart_name column charaters limit from 64 to 128.
				$wpdb->query( "ALTER TABLE $tbl_saved_cart CHANGE cart_name cart_name VARCHAR(128)" );
			}
		}
	}

	public function migration_options_2_0_0() {
		global $wpdb;

		if ( version_compare( $this->db_plugin_version, '2.0.0', '<' ) ) {
			$tbl_shared_cart = $wpdb->prefix . 'wcss_shared_cart';
			$tbl_saved_cart  = $wpdb->prefix . 'wcss_saved_cart';

			if ( $wpdb->get_var( "SHOW TABLES LIKE '$tbl_shared_cart'" ) == $tbl_shared_cart ) {
				if ( $wpdb->get_var( "SHOW COLUMNS FROM $tbl_shared_cart WHERE Field = 'cart_created' AND Type LIKE '%varchar%'" ) ) {
					$shared_carts = $wpdb->get_results( "SELECT * FROM $tbl_shared_cart" );

					if ( $shared_carts ) {
						foreach ( $shared_carts as $shared_cart ) {
							$cart_created = gmdate( 'Y-m-d H:i:s', strtotime( $shared_cart->cart_created ) );
							$wpdb->query( "UPDATE $tbl_shared_cart SET cart_created = '$cart_created' WHERE id = '{$shared_cart->id}'"  );
						}
					}

					$wpdb->query( "ALTER TABLE $tbl_shared_cart CHANGE cart_created cart_created DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP" );
				}

				if ( $wpdb->get_var( "SHOW COLUMNS FROM $tbl_shared_cart WHERE Field = 'cart_retrieved_time' AND Type LIKE '%varchar%'" ) ) {
					$shared_carts = $wpdb->get_results( "SELECT * FROM $tbl_shared_cart" );

					if ( $shared_carts ) {
						foreach ( $shared_carts as $shared_cart ) {
							if ( $shared_cart->cart_retrieved_time ) {
								$cart_retrieved_time = gmdate( 'Y-m-d H:i:s', strtotime( $shared_cart->cart_retrieved_time ) );
								$wpdb->query( "UPDATE $tbl_shared_cart SET cart_retrieved_time = '$cart_retrieved_time' WHERE id = '{$shared_cart->id}'"  );
							} else {
								$wpdb->query( "UPDATE $tbl_shared_cart SET cart_retrieved_time = NULL WHERE id = '{$shared_cart->id}'"  );
							}
						}
					}

					$wpdb->query( "ALTER TABLE $tbl_shared_cart CHANGE cart_retrieved_time cart_retrieved_time VARCHAR(32)" );
					$wpdb->query( "UPDATE $tbl_shared_cart SET cart_retrieved_time = NULL WHERE cart_retrieved_time = ''" );
					$wpdb->query( "ALTER TABLE $tbl_shared_cart CHANGE cart_retrieved_time cart_retrieved_time DATETIME NULL" );
				}
			}

			if ( $wpdb->get_var( "SHOW TABLES LIKE '$tbl_saved_cart'" ) == $tbl_saved_cart ) {
				if ( $wpdb->get_var( "SHOW COLUMNS FROM $tbl_saved_cart WHERE Field = 'cart_saved' AND Type LIKE '%varchar%'" ) ) {
					$saved_carts = $wpdb->get_results( "SELECT * FROM $tbl_saved_cart" );

					if ( $saved_carts ) {
						foreach ( $saved_carts as $saved_cart ) {
							$cart_saved = gmdate( 'Y-m-d H:i:s', strtotime( $saved_cart->cart_saved ) );
							$wpdb->query( "UPDATE $tbl_saved_cart SET cart_saved = '$cart_saved' WHERE id = '{$saved_cart->id}'"  );
						}
					}

					$wpdb->query( "ALTER TABLE $tbl_saved_cart CHANGE cart_saved cart_saved DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP" );
				}
			}
		}
	}

	/**
	 * Add option only if not exists.
	 *
	 * @param string $option
	 * @param mixed  $value
	 * @return boolean
	 */
	public function add_option( $option, $value ) {
		if ( get_option( $option ) === false ) {
			add_option( $option, $value );
		}
	}

	/**
	 * Get previous installed plugin version.
	 *
	 * @since 2.0.0
	 *
	 * @return string Previous installed plugin version.
	 */
	protected function get_db_plugin_version() {
		return get_option( 'wcss_version' );
	}

} // End of the class WCSS_Migration

return new WCSS_Migration();
