<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Legacy saved cart.
 *
 * Legacy and deprecated functions are here to keep the WCSS_Saved_Cart class clean.
 * This class will be removed in future versions.
 *
 */
abstract class WCSS_Legacy_Saved_Cart {

	/**
	 * Contains the saved cart table name.
	 *
	 * @var string Saved cart table name.
	 */
	private $table_name;

	/**
	 * Class constructor.
	 */
	public function __construct() {
		global $wpdb;

		$this->table_name = $wpdb->prefix . 'wcss_saved_cart';
	}

	/**
	 * Insert row into the saved cart database.
	 *
	 * @param int    $user_id    User ID.
	 * @param string $cart_name  Cart name.
	 * @param string $cart_key   Cart key.
	 * @param string $cart_saved Cart saved.
	 * @return int Inserted row ID.
	 */
	public function insert( $user_id, $cart_name, $cart_key, $cart_saved = '' ) {
		global $wpdb;

		if ( ! $cart_saved ) {
			$cart_saved = wcss_current_time();
		}

		$wpdb->insert(
			$this->table_name,
			array(
				'user_id'    => $user_id,
				'cart_name'  => $cart_name,
				'cart_key'   => $cart_key,
				'cart_saved' => $cart_saved,
			),
			array(
				'%d',
				'%s',
				'%s',
				'%s',
			)
		);

		return $wpdb->insert_id;
	}

	/**
	 * Delete all the rows and data and make saved cart table empty.
	 *
	 * @return bool True on success, false on failure.
	 */
	public function truncate() {
		global $wpdb;
		return $wpdb->query( "TRUNCATE TABLE {$this->table_name}" );
	}

	/**
	 * Delete saved cart by cart key.
	 *
	 * @param string $cart_key Cart key.
	 * @return int Number of affected rows.
	 */
	public function delete_saved_cart( $cart_key ) {
		global $wpdb;

		return $wpdb->delete(
			$this->table_name,
			array( 'cart_key' => $cart_key ),
			array( '%s' )
		);
	}

	/**
	 * Delete saved cart by user or by cart key and user ID
	 *
	 * @param string $cart_key Saved cart key.
	 * @param int    $user_id  User ID.
	 * @return int Number of affected rows.
	 */
	public function user_delete_saved_cart( $cart_key, $user_id ) {
		global $wpdb;

		return $wpdb->query(
			$wpdb->prepare(
				"DELETE FROM $this->table_name
				 WHERE cart_key = %s
				 AND user_id = %d",
				$cart_key,
				$user_id
			)
		);
	}

	/**
	 * Get all saved carts.
	 *
	 * @return array List of saved carts.
	 */
	public function get_all_saved_cart() {
		global $wpdb;

		return $wpdb->get_results(
			"SELECT *
			FROM {$wpdb->prefix}wcss_saved_cart",
			ARRAY_A
		);
	}

	/**
	 * Get list of saved cart by user ID.
	 *
	 * @param int $user_id
	 * @return array list of saved cart.
	 */
	public function get_saved_cart_by_user_id( $user_id ) {
		global $wpdb;

		return $wpdb->get_results(
			$wpdb->prepare(
				"SELECT *
				FROM {$wpdb->prefix}wcss_saved_cart
				WHERE user_id = %d
				ORDER BY id DESC",
				$user_id
			),
			ARRAY_A
		);
	}

	/**
	 * Check whether cart is saved or not.
	 *
	 * @since 1.7.2
	 *
	 * @param string $cart_key Saved cart.
	 * @return bool True if cart is saved. False otherwise.
	 */
	public function is_cart_saved( $cart_key ) {
		global $wpdb;

		$is_saved = $wpdb->get_var(
			$wpdb->prepare(
				"SELECT id
				FROM {$this->table_name}
				WHERE cart_key = %s",
				$cart_key
			)
		);

		return $is_saved ? true : false;
	}
}
