<?php
	$wcss_save_cart_form_fields = apply_filters(
		'wcss_save_cart_form_fields',
		array(
			'cart_name' => array(
				'title'      => get_option( 'wcss_save_cart_input_placeholder' ),
				'type'       => 'text',
				'required'   => true,
				'name'       => 'wcss_save_cart[cart_name]',
				'attributes' => array(
					'placeholder' => get_option( 'wcss_save_cart_input_placeholder' ),
					'maxlength'   => 128,
					'autofocus'   => 'autofocus',
				),
			),

			'cart_key' => array(
				'type'       => 'hidden',
				'name'       => 'wcss_save_cart[cart_key]',
				'value'      => $uid,
				'attributes' => array(
					'autocomplete' => 'autocomplete_off_hack',
				),
			),
		)
	);
?>

<div class="wcss-save-cart-form">

	<form id="wcss-save-cart-form" action="#" method="post">
		<input type="hidden" name="wcss_save_cart_submit" value="submit">

		<div class="wcz_wcs-popup--text-color">
			<?php echo esc_html( get_option( 'wcss_save_cart_message' ) ); ?>
		</div>

		<?php
			foreach ( $wcss_save_cart_form_fields as $field_key => $field )  {
				if ( ! isset( $field['type'] ) ) {
					continue;
				}

				$title    = isset( $field['title'] ) ? $field['title'] : '';
				$desc     = isset( $field['desc'] ) ? $field['desc'] : '';
				$required = isset( $field['required'] ) && true === $field['required'] ? 'required="required"' : '';
				$name     = isset( $field['name'] ) ? $field['name'] : '';
				$value    = isset( $field['value'] ) ? $field['value'] : '';
				$class    = isset( $field['class'] ) ? $field['class'] : '';
				$options  = isset( $field['options'] ) ? $field['options'] : array();

				// Custom attribute handling.
				$attributes = array();

				if ( ! empty( $field['attributes'] ) && is_array( $field['attributes'] ) ) {
					foreach ( $field['attributes'] as $attribute => $attribute_value ) {
						$attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $attribute_value ) . '"';
					}
					$field['attributes'] = $attributes;
				}

				if ( 'text' === $field['type'] ) {
					echo wp_sprintf(
						'<input type="text" name="%1$s" required="required" %2$s %3$s />',
						esc_html( $name ),
						$required,
						implode( ' ', $attributes )
					);
				} else if ( 'hidden' === $field['type'] ) {
					echo wp_sprintf(
						'<input type="hidden" name="%1$s" value="%2$s" />',
						esc_html( $name ),
						$value
					);
				} else if ( 'select' === $field['type'] ) {
					?>
					<select name="<?php echo esc_html( $name ) ?>" <?php echo $required; ?> <?php echo implode( ' ', $attributes ); ?>>
						<?php foreach( $options as $option_value => $option_name ) : ?>
							<option value="<?php echo esc_attr( $option_value ); ?>" <?php selected( $option_value, $value ) ?> ><?php echo esc_html( $option_name ); ?></option>
						<?php endforeach; ?>
					</select>
					<?php
				} else if ( 'textarea' === $field['type'] ) {
					echo wp_sprintf(
						'<textarea name="%1$s" %2$s %3$s>%4$s</textarea>',
						esc_attr( $name ),
						$required,
						implode( ' ', $attributes ),
						$value
					);
				}
			}
		?>

		<input type="submit" class="button btn btn-primary wcss-btn" value="<?php echo esc_attr( get_option( 'wcss_save_cart_button_text' ) ); ?>">

	</form>

</div>
